@@ -15,6 +15,8 @@ import types
 import typing
 from typing import Any, TypeVar, Union, Callable, Optional
 
+from .eval_forward_refs import get_evaled_dataclass_fields
+from .dataclass_protocol import DataclassProtocol
 from .is_instance import get_container_type, is_instance
 from .str_to_bool import to_bool
 
@@ -54,9 +56,11 @@ def to_datetime(value: Union[str, int, float]) -> datetime.datetime:
         return datetime.datetime.fromisoformat(value)
     return datetime.datetime.fromtimestamp(value)
 
+
 def pass_value(value: Any) -> Any:
     return value
 
+
 @functools.cache
 def get_converter(type_: type | types.GenericAlias | types.UnionType) -> Callable[[Any], Any]:
     type_origin = getattr(type_, '__origin__', None)
@@ -144,6 +148,7 @@ class UnsupportedType(TypeError):
 
 
 T = TypeVar('T')
+DP = TypeVar('DP', bound=DataclassProtocol)
 
 
 class NoValue:
@@ -196,15 +201,15 @@ def convert(name: str, type_: type[T], init: bool, default: Any, default_factory
                 value = dict_to_dataclass({}, type_)
             except FieldErrors as e:
                 for field, error in e.field_to_error.items():
-                    write_to_dict_or_raise(field_name_to_error, key=f'{type_}.{field}', exception=error)
+                    write_to_dict_or_raise(field_name_to_error, key=f'{name}.{field}', exception=error)
         else:
-            write_to_dict_or_raise(field_name_to_error, type_, MissingField())
+            write_to_dict_or_raise(field_name_to_error, name, MissingField())
             return NoValue
 
     return value
 
 
-def dict_to_dataclass(dict_value: dict[str, Any], dataclass: type[T]) -> T:
+def dict_to_dataclass(dict_value: dict[str, Any], dataclass: type[DP]) -> DP:
     if not dataclasses.is_dataclass(dataclass):
         raise TypeError("expected dataclass type")
 
@@ -213,7 +218,7 @@ def dict_to_dataclass(dict_value: dict[str, Any], dataclass: type[T]) -> T:
 
     args = {}
     field_name_to_field = get_dataclass_field_name_to_field(dataclass)
-    field_name_to_type = typing.get_type_hints(dataclass)
+    field_name_to_type = typing.get_type_hints(dataclass) | get_evaled_dataclass_fields(dataclass)
     field_name_to_error = {}
     if hasattr(dict_value, "get"):
         get_value = dict_value.get
